summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Wu <david_wu@quanta.corp-partner.google.com>2019-08-07 13:59:21 +0800
committerFurquan Shaikh <furquan@google.com>2019-08-15 20:07:36 +0000
commit8444e3c47a98ff5f46ec43d711f04145e061026e (patch)
tree6a416ecc59276727e4e20c8f7b882022b5905da9
parent2c430c8c5b75f9d8b99c0f9358eea3470aa4f7ed (diff)
downloadcoreboot-8444e3c47a98ff5f46ec43d711f04145e061026e.tar.gz
coreboot-8444e3c47a98ff5f46ec43d711f04145e061026e.tar.bz2
coreboot-8444e3c47a98ff5f46ec43d711f04145e061026e.zip
mb/google/hatch/var/kindred: Disable eMMC for new SKU ID 23 and 24
1. Disable eMMC controller for new SKU ID 23 and 24 2. Disable HS400 mode BUG=b:132918661 TEST=Verify eMMC is disabled when SKU ID = 1/3/23/24 Change-Id: I0d893f0f7339e7b1a1e6b56d1598c0a361c8d604 Signed-off-by: David Wu <david_wu@quanta.corp-partner.google.com> Reviewed-on: https://review.coreboot.org/c/coreboot/+/34788 Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Tim Wawrzynczak <twawrzynczak@chromium.org> Reviewed-by: Paul Fagerburg <pfagerburg@chromium.org>
-rw-r--r--src/mainboard/google/hatch/variants/kindred/variant.c9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/mainboard/google/hatch/variants/kindred/variant.c b/src/mainboard/google/hatch/variants/kindred/variant.c
index 14b26ed10ce6..54059477a1af 100644
--- a/src/mainboard/google/hatch/variants/kindred/variant.c
+++ b/src/mainboard/google/hatch/variants/kindred/variant.c
@@ -14,6 +14,7 @@
*/
#include <baseboard/variants.h>
+#include <chip.h>
#include <soc/pci_devs.h>
#include <ec/google/chromeec/ec.h>
@@ -21,14 +22,16 @@ void variant_devtree_update(void)
{
uint32_t sku_id;
struct device *emmc_host;
-
+ config_t *cfg = config_of_path(SA_DEVFN_ROOT);
emmc_host = pcidev_path_on_root(PCH_DEVFN_EMMC);
if (emmc_host == NULL)
return;
/* SKU ID 1, 3 doesn't have a eMMC device, hence disable it. */
sku_id = get_board_sku();
- if (sku_id == 1 || sku_id == 3)
+ if (sku_id == 1 || sku_id == 3 || sku_id == 23 || sku_id == 24) {
emmc_host->enabled = 0;
+ cfg->ScsEmmcHs400Enabled = 0;
+ }
}
@@ -21,14 +22,16 @@ void variant_devtree_update(void)
if (emmc_host == NULL)
return;
- /* SKU ID 1, 3 doesn't have a eMMC device, hence disable it. */
+ /* SKU ID 1/3/23/24 doesn't have a eMMC device, hence disable it. */
sku_id = get_board_sku();